"""Pages for genetics-viz."""

# Import page modules to register routes when this module is imported
from genetics_viz.pages import cohort, diagnostic, search, validation

__all__ = ["cohort", "diagnostic", "search", "validation"]
